import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { NewService } from '../../service/core/new.service';
import { CDTO_new, CVO_new, FVO_new, QDTO_new, QVO_new, UDTO_new, UVAO_new } from '../../interface/core/new.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['政策法规'])
@Controller('/new')
export class NewController extends BaseController {
  @Inject()
  service: NewService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_new })
  async create(@Body() data: CDTO_new) {
    const dbData = await this.service.create(data);
    const result = new CVO_new(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_new })
  async query(@Query() filter: QDTO_new, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_new(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/queryTotal')
  @ApiQuery({ name: 'queryTotal' })
  @ApiResponse({ type: QVO_new })
  async queryTotal(@Query() filter: QDTO_new) {
    const list = await this.service.queryTotal(filter);
    return list;
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_new })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_new(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_new })
  async update(@Param('id') id: string, @Body() body: UDTO_new) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
