import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { RecordService } from '../../service/core/record.service';
import { CDTO_record, CVO_record, FVO_record, QDTO_record, QVO_record, UDTO_record, UVAO_record } from '../../interface/core/record.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['用户观看记录'])
@Controller('/record')
export class RecordController extends BaseController {
  @Inject()
  service: RecordService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_record })
  async create(@Body() data: CDTO_record) {
    const dbData = await this.service.createBefore(data);
    const result = new CVO_record(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_record })
  async query(@Query() filter: QDTO_record, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_record(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/special')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_record })
  async special() {
    const list = await this.service.special(this.ctx.filter);
    const data = list.data;
    const total = list.total;
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_record })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_record(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_record })
  async update(@Param('id') id: string, @Body() body: UDTO_record) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
