import { Provide } from '@midwayjs/decorator';
import { InjectEntityModel } from '@midwayjs/typegoose';
import { ReturnModelType } from '@typegoose/typegoose';
import { BaseService } from 'free-midway-component';
import { Record } from '../../entity/core/record.entity';
import { get } from 'lodash';
import { Video } from '../../entity/core/video.entity';
import { User } from '../../entity/system/user.entity';
import { Course } from '../../entity/core/course.entity';
type modelType = ReturnModelType<typeof Record>;
@Provide()
export class RecordService extends BaseService<modelType> {
  @InjectEntityModel(Record)
  model: modelType;
  @InjectEntityModel(Video)
  vModel: ReturnModelType<typeof Video>;
  @InjectEntityModel(User)
  uModel: ReturnModelType<typeof User>;
  @InjectEntityModel(Course)
  cModel: ReturnModelType<typeof Course>;

  // 特殊查询
  async special(filter) {
    const { skip = 0, limit = 0, user_name, video_name, course_name, ...info } = filter;
    if (user_name) {
      const userData = await this.uModel.findOne({ nick_name: user_name }).lean();
      if (userData) info.user_id = get(userData, '_id');
    }
    if (video_name) {
      const videoData = await this.vModel.findOne({ title: { $regex: video_name } }).lean();
      if (videoData) info.video_id = get(videoData, '_id');
    }
    if (course_name) {
      const courseData = await this.cModel.findOne({ title: { $regex: course_name } }).lean();
      if (courseData) info.course_id = get(courseData, '_id');
    }
    const data = await this.model.find(info).skip(skip).limit(limit).lean();
    for (const val of data) {
      if (get(val, 'user_id')) {
        // 查询用户信息
        const userData = await this.uModel.findById(val.user_id).lean();
        if (userData) Object.assign(val, { user_name: userData.nick_name });
      }
      if (get(val, 'video_id')) {
        // 查询视频信息
        const videoData = await this.vModel.findById(val.video_id).lean();
        if (videoData) Object.assign(val, { videoInfo: videoData, video_name: videoData.title });
      }
      if (get(val, 'course_id')) {
        // 查询视频信息
        const courseData = await this.cModel.findById(val.course_id).lean();
        if (courseData) Object.assign(val, { courseInfo: courseData, course_name: courseData.title });
      }
    }
    const total = await this.model.count(info);
    return { data, total };
  }
  // 特殊创建
  async createBefore(data) {
    const { user_id, video_id, course_id, total_time, ...info } = data;
    const calculate = parseInt(((get(info, 'time') / total_time) * 100).toFixed(2));
    if (calculate > 80) {
      const videoData = await this.vModel.findById(video_id).lean();
      info.hour = get(videoData, 'hour');
      data.hour = get(videoData, 'hour');
    }
    let result;
    const record = await this.model.findOne({ user_id, video_id, course_id }).lean();
    if (record) {
      if (get(record, 'time') < get(info, 'time')) {
        await this.model.updateOne({ _id: get(record, '_id') }, info);
        result = await this.model.findById(get(record, '_id'));
      }
    } else {
      result = await this.model.create(data);
    }
    return result;
  }
}
